==> troubleshooter-1.0.1.tar.gz: troubleshooter-1.0.1/troubleshooter/proposer/knowledge_base/common_exp_lib.py <==
# Copyright 2022 Tiger Miao
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================

template_exprience_list_cn = [
    {"Fault Name": "",
     "Key Log Information": "",
     "Key Python Stack Information": "",
     "Key C++ Stack Information": "",
     "Fault Cause": "",
     "Modification Suggestion": "",
     "Fault Case": ""}
]

default_experience_list_cn = [
    {"Fault Name": "MindSpore通用故障",
     "Key Log Information": "",
     "Key Python Stack Information": "",
     "Key C++ Stack Information": "",
     "Fault Cause": "1. 当前故障未能找到匹配的故障分析知识库; ",
     "Modification Suggestion": "请参考MindSpore 错误分析方法、FAQ进行问题排查或者在社区查询提问。",
     "Fault Case": "1. 官网错误分析： "
                    "https://www.mindspore.cn/tutorials/experts/zh-CN/r1.8/debug/error_analyze.html "
                   "2. MindSpore FAQ: "
                   "https://www.mindspore.cn/docs/zh-CN/r1.8/faq/installation.html "
                   "3. 社区案例: "
                   "https://bbs.huaweicloud.com/forum/forum-1076-2704-1.html"}
]

==> troubleshooter-1.0.6.tar.gz: troubleshooter-1.0.6/troubleshooter/proposer/knowledge_base/common_exp_lib.py <==
# Copyright 2022 Tiger Miao and collaborators.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================

template_exprience_list_cn = [
    {"Fault Name": "",
     "Key Log Information": "",
     "Key Python Stack Information": "",
     "Key C++ Stack Information": "",
     "Fault Cause": "",
     "Modification Suggestion": "",
     "Fault Case": ""}
]

default_experience_list_cn = [
    {"ID": "common_id_1",
     "Fault Name": "MindSpore通用故障",
     "Key Log Information": "",
     "Key Python Stack Information": "",
     "Key C++ Stack Information": "",
     "Fault Cause": "1. 当前故障未能找到匹配的故障分析知识库; ",
     "Modification Suggestion": "请参考MindSpore 错误分析方法、FAQ进行问题排查或者在社区查询提问。",
     "Fault Case": "1. 官网功能调试分析： "
                    "https://www.mindspore.cn/tutorials/experts/zh-CN/master/debug/function_debug.html "
                   "2. MindSpore FAQ: "
                   "https://www.mindspore.cn/docs/zh-CN/master/faq/installation.html "
                   "3. 社区案例: "
                   "https://bbs.huaweicloud.com/forum/forum-1076-2704-1.html"}
]
